@@ -1,59 +1,60 @@
 from typing import List, Optional
 from ddd_objects.domain.entity import Entity, ExpiredEntity
 from .value_obj import (
-    InstanceTypeStatusCategory,
-    TimeInterval,
-    ServiceType,
-    Status,
-    InternetPayType,
-    DomainName,
-    Path,
-    Key,
-    Subdomain,
-    NodeStatus,
-    Version,
-    Hostname,
-    Output,
-    Password,
-    RecordID,
-    Command,
-    ZoneID,
+    KeyType,
     GPUType,
-    Usage,
-    NodeLabel,
-    DNSLine,
-    BandWidth,
-    Weight,
-    Endpoint,
-    IngressHost,
-    NodeName,
-    Name,
+    InstanceTypeStatusCategory,
+    ZoneID,
+    DomainName,
+    InternetPayType,
     ImageID,
     Number,
-    Size,
-    InstanceType,
-    DateTime,
-    IP,
-    Port,
-    Value,
-    ID,
-    InstanceID,
-    DNSType,
-    Username,
-    KeyType,
-    InstanceName,
-    SecurityGroupID,
     InstanceTypeStatus,
-    RegionID,
-    Bool,
-    Data,
-    Price,
-    Type,
-    Time,
-    NodeType,
-    Token,
+    PodStatus,
+    Output,
     Info,
-    PayType
+    TimeInterval,
+    ServiceType,
+    Value,
+    Name,
+    Port,
+    BandWidth,
+    Subdomain,
+    Data,
+    Key,
+    Price,
+    InstanceName,
+    RegionID,
+    Version,
+    Status,
+    InstanceID,
+    Path,
+    SecurityGroupID,
+    Weight,
+    NodeName,
+    NodeType,
+    Command,
+    Size,
+    Time,
+    NodeStatus,
+    Usage,
+    Endpoint,
+    Hostname,
+    DNSLine,
+    IP,
+    InstanceType,
+    Token,
+    ID,
+    PayType,
+    DateTime,
+    Username,
+    IngressHost,
+    DNSType,
+    RecordID,
+    Type,
+    Password,
+    Bool,
+    NodeLabel
 )
 
 class Condition(Entity):
@@ -514,7 +515,7 @@ class Pod(ExpiredEntity):
         self,
         name: Name,
         node_name: NodeName,
-        status: Status,
+        pod_status: PodStatus,
         age: TimeInterval,
         pod_ip: IP,
         namespace: Name,
@@ -524,7 +525,7 @@ class Pod(ExpiredEntity):
     ):
         self.name=name
         self.node_name=node_name
-        self.status=status
+        self.pod_status=pod_status
         self.age=age
         self.pod_ip=pod_ip
         self.namespace=namespace
