@@ -1,108 +1,109 @@
 from typing import List
 from ddd_objects.infrastructure.converter import Converter
 from ..domain.entity import (
-    Secret,
-    InstanceUserSetting,
-    PodOSSOperationInfo,
-    NodeInfo,
-    InstanceTypeUserSetting,
     OSSOperationInfo,
     Condition,
-    InstanceTypeWithStatus,
-    ConfigMapUserSetting,
-    ResourceOSSSetting,
     NodeMeta,
-    ConfigMap,
-    Deployment,
-    DNSRecord,
+    InstanceUserSetting,
     NodeUserSetting,
-    SecretUserSetting,
+    CommandResult,
+    ConfigMapUserSetting,
     Ingress,
+    ConfigMap,
     CommandSetting,
     Namespace,
+    PodOSSOperationInfo,
+    Secret,
     InstanceInfo,
+    InstanceTypeWithStatus,
     Service,
-    CommandResult,
-    Pod
+    DNSRecord,
+    SecretUserSetting,
+    NodeInfo,
+    Pod,
+    ResourceOSSSetting,
+    Deployment,
+    InstanceTypeUserSetting
 )
 from ..domain.value_obj import (
-    InstanceTypeStatusCategory,
-    TimeInterval,
-    ServiceType,
-    Status,
-    InternetPayType,
-    DomainName,
-    Path,
-    Key,
-    Subdomain,
-    NodeStatus,
-    Version,
-    Hostname,
-    Output,
-    Password,
-    RecordID,
-    Command,
-    ZoneID,
+    KeyType,
     GPUType,
-    Usage,
-    NodeLabel,
-    DNSLine,
-    BandWidth,
-    Weight,
-    Endpoint,
-    Name,
-    NodeName,
+    InstanceTypeStatusCategory,
+    ZoneID,
+    DomainName,
+    InternetPayType,
     ImageID,
     Number,
-    Size,
-    InstanceType,
-    DateTime,
-    IP,
-    Port,
-    Value,
-    ID,
-    InstanceID,
-    DNSType,
-    Username,
-    KeyType,
-    InstanceName,
-    SecurityGroupID,
     InstanceTypeStatus,
-    RegionID,
-    Bool,
-    Data,
-    Price,
-    Type,
-    Time,
-    NodeType,
-    Token,
+    PodStatus,
+    Output,
     Info,
-    PayType
+    TimeInterval,
+    ServiceType,
+    Value,
+    Name,
+    Port,
+    BandWidth,
+    Subdomain,
+    Data,
+    Key,
+    Price,
+    InstanceName,
+    RegionID,
+    Version,
+    Status,
+    InstanceID,
+    Path,
+    SecurityGroupID,
+    Weight,
+    NodeName,
+    NodeType,
+    Command,
+    Size,
+    Time,
+    NodeStatus,
+    Usage,
+    Endpoint,
+    Hostname,
+    DNSLine,
+    IP,
+    InstanceType,
+    Token,
+    ID,
+    PayType,
+    DateTime,
+    Username,
+    DNSType,
+    RecordID,
+    Type,
+    Password,
+    Bool,
+    NodeLabel
 )
 from .do import (
-    OSSOperationInfoDO,
-    ResourceOSSSettingDO,
+    IngressDO,
+    SecretDO,
     InstanceInfoDO,
-    InstanceUserSettingDO,
     NodeMetaDO,
-    NodeInfoDO,
-    CommandResultDO,
-    ServiceDO,
-    ConfigMapDO,
+    NamespaceDO,
     ConditionDO,
-    InstanceTypeUserSettingDO,
     DNSRecordDO,
     SecretUserSettingDO,
-    ConfigMapUserSettingDO,
-    CommandSettingDO,
-    NodeUserSettingDO,
-    NamespaceDO,
-    PodOSSOperationInfoDO,
-    SecretDO,
+    OSSOperationInfoDO,
     PodDO,
-    DeploymentDO,
+    CommandSettingDO,
+    PodOSSOperationInfoDO,
+    ConfigMapUserSettingDO,
+    ResourceOSSSettingDO,
+    CommandResultDO,
+    InstanceTypeUserSettingDO,
+    InstanceUserSettingDO,
     InstanceTypeWithStatusDO,
-    IngressDO
+    ConfigMapDO,
+    ServiceDO,
+    NodeUserSettingDO,
+    DeploymentDO,
+    NodeInfoDO
 )
 
 class ConditionConverter(Converter):
@@ -288,7 +289,7 @@ class PodConverter(Converter):
         return Pod(
             name = Name(do.name),
             node_name = NodeName(do.node_name),
-            status = Status(do.status),
+            pod_status = PodStatus(do.pod_status),
             age = TimeInterval(do.age),
             pod_ip = IP(do.pod_ip),
             namespace = Name(do.namespace),
@@ -300,7 +301,7 @@ class PodConverter(Converter):
         return PodDO(
             name = None if x.name is None else x.name.get_value(),
             node_name = None if x.node_name is None else x.node_name.get_value(),
-            status = None if x.status is None else x.status.get_value(),
+            pod_status = None if x.pod_status is None else x.pod_status.get_value(),
             age = None if x.age is None else x.age.get_value(),
             pod_ip = None if x.pod_ip is None else x.pod_ip.get_value(),
             namespace = None if x.namespace is None else x.namespace.get_value(),
